import React, { Component } from 'react';
import { PropTypes } from 'prop-types';

var propTypes$1 = {
  breakPoints: PropTypes.arrayOf(PropTypes.number),
  rowItems: PropTypes.arrayOf(PropTypes.number)
};
var defaultProps = {
  breakPoints: [640, 900, 1280],
  rowItems: [2, 3, 4]
};

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();







var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};



var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};











var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};



















var toConsumableArray = function (arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  } else {
    return Array.from(arr);
  }
};

function getBreak(props) {
  var breakPoints = props.breakPoints;

  var index = getIndex(breakPoints, window.outerWidth);
  return {
    breakPoint: index === -1 ? -1 : breakPoints[index]
  };
}
function shouldUpdate(state, props) {
  var breakPoint = state.breakPoint;
  var breakPoints = props.breakPoints;

  var currentIndex = breakPoints.indexOf(breakPoint);
  var nextIndex = getIndex(breakPoints, window.outerWidth);
  return currentIndex !== nextIndex ? true : false;
}
function getIndex(breakPoints, width) {
  return [].concat(toConsumableArray(breakPoints), [width]).sort(function (a, b) {
    return a - b;
  }).indexOf(width) - 1;
}

function itemStyles(state, props) {
  var breakPoint = state.breakPoint;
  var breakPoints = props.breakPoints,
      rowItems = props.rowItems;

  var index = breakPoints.indexOf(breakPoint);
  return {
    flexBasis: index === -1 ? '100%' : 100 / rowItems[index] + '%'
  };
}

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".flex__container{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.flex__item{-webkit-box-sizing:border-box;box-sizing:border-box;-ms-flex-preferred-size:100%;flex-basis:100%}";
styleInject(css);

var Flex = function (_Component) {
  inherits(Flex, _Component);

  function Flex(props) {
    classCallCheck(this, Flex);

    var _this = possibleConstructorReturn(this, (Flex.__proto__ || Object.getPrototypeOf(Flex)).call(this, props));

    _this.setBreakPoint = function () {
      if (shouldUpdate(_this.state, _this.props)) {
        _this.setState(_extends({}, _this.state, getBreak(_this.props)));
      }
    };

    _this.state = {
      breakPoint: -1
    };
    return _this;
  }

  createClass(Flex, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      var _this2 = this;

      this.setBreakPoint();
      window.addEventListener('resize', function () {
        return _this2.setBreakPoint(_this2.state, _this2.props);
      });
    }
  }, {
    key: 'componentWillUpdate',
    value: function componentWillUpdate(nextProps, nextState) {
      if (this.props !== nextProps) {
        this.setState(_extends({}, nextState, getBreak(nextProps)));
      }
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      window.removeEventListener('resize', this.setBreakPoint);
    }
  }, {
    key: 'render',
    value: function render() {
      var styles = itemStyles(this.state, this.props);
      var flexItems = this.props.children.map(function (item, index) {
        return React.createElement(
          'div',
          { key: index, className: 'flex__item', style: styles },
          React.createElement(
            'div',
            { className: 'flex__content' },
            item
          )
        );
      });
      return React.createElement(
        'div',
        { className: 'flex' },
        React.createElement(
          'div',
          { className: 'flex__container' },
          flexItems
        )
      );
    }
  }]);
  return Flex;
}(Component);

Flex.propTypes = propTypes$1;
Flex.defaultProps = defaultProps;

export default Flex;
